@@ -2,7 +2,7 @@
 This module is callable via the command line
 but importing it does nothing
 """
-from install_nginx import install_nginx
+from .install_nginx import install_nginx
 
 
 def main():
